==> haskell-pantry-0.1.1.1-62-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pantry.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pantry
version: 0.1.1.1
id: pantry-0.1.1.1-9rq4hxwclrA2GNYOHBx73M
key: pantry-0.1.1.1-9rq4hxwclrA2GNYOHBx73M
license: BSD-3-Clause
copyright: 2018-2019 FP Complete
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/commercialhaskell/stack#readme
synopsis: Content addressable Haskell package management
description:
    Please see the README on Github at <https://github.com/commercialhaskell/stack/blob/master/subs/pantry/README.md>
category: Development
abi: 1704953944d2c9b3b0f8c4db8c244926
exposed: True
exposed-modules:
    Pantry Pantry.Internal Pantry.Internal.AesonExtended
    Pantry.Internal.Companion Pantry.Internal.Stackage
    Pantry.Internal.StaticBytes Pantry.SHA256
hidden-modules: Hackage.Security.Client.Repository.HttpLib.HttpClient
                Pantry.Archive Pantry.HTTP Pantry.HPack Pantry.Hackage Pantry.Repo
                Pantry.SQLite Pantry.Storage Pantry.Tree Pantry.Types
                System.IsWindows
import-dirs: /usr/lib/ghc-8.6.5/site-local/pantry-0.1.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/pantry-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/pantry-0.1.1.1
hs-libraries: HSpantry-0.1.1.1-9rq4hxwclrA2GNYOHBx73M
depends:
    Cabal-2.4.0.1 aeson-1.4.6.0-6SSxkzo3COEI5l1mOYJmxL
    ansi-terminal-0.9.1-JvtMBmSUh1eHKvsAMwthXj array-0.5.3.0
    base-4.12.0.0 base-orphans-0.8.1-6XlhSm6oZf21np9NDzyPU3
    base64-bytestring-1.0.0.2-27dSAr8bLTq6kAjQ5MgzSz
    bytestring-0.10.8.2 conduit-1.3.1.1-7uQvxkXSawE7t4T2ZzYFLO
    conduit-extra-1.3.4-A6uYuJUr0NV2BK9tpZGRHv containers-0.6.0.1
    contravariant-1.5.2-IGTyLqhZC2pCTY0qng5HHQ
    cryptonite-0.26-3rNbQlBz8Bk2f3GtKAwmMo
    cryptonite-conduit-0.2.2-IbyRvMP6FR7315oHqgehPm deepseq-1.4.4.0
    digest-0.0.1.2-EmnqrtISorTAzGzJuIqcyN directory-1.3.3.0
    filelock-0.1.1.3-FiB0yXqMtv43yiGSEcPU8N filepath-1.4.2.1
    generic-deriving-1.12.4-35jn1EpQs9wLkrWud50div ghc-prim-0.5.3
    hackage-security-0.5.3.0-BRvLWPjeAMBHmRNJmFQnO
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    hpack-0.33.0-IVQgYWk2EgaG6Dk4FFcccX
    http-client-0.6.4-IYZM7eWNkdh6wFMVK3AnMc
    http-client-tls-0.3.5.3-2b5Qtcr5S3K5iKSJDujdKc
    http-conduit-2.3.7.3-JoPCXGUvu2x76EWhwPIHU9
    http-download-0.1.0.0-9uzCD8UzQD42Gqf6uJg0WX
    http-types-0.12.3-HC8QVCkRWraINFy4YJ7OYV integer-gmp-1.0.2.0
    memory-0.14.18-BrsHMbfyYBXCzXvPhAexth
    mono-traversable-1.0.13.0-oJJbAcoxvEL7oYbbGdR73 mtl-2.2.2
    network-2.8.0.0-GWaLTJJGEavAfd7Abho21R
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    path-0.6.1-7qyDqq3ByCz1rjCGJoUF5M
    path-io-1.4.2-GJEDmT1RyHQFOlBb1mlAac
    persistent-2.10.4-Fl5pGLKSbCo786yQ0tRhla
    persistent-sqlite-2.10.5-FrfeAGNgQH4C0G6kmfeZkJ
    persistent-template-2.7.3-2Ja5HZ9f2B57e6SIMZOkpX
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0
    rio-0.1.12.0-80NoB2Bd2PqDjgUOhHFb0N
    rio-orphans-0.1.1.0-GgEYniWigW2L6GAlVbN1LL
    rio-prettyprint-0.1.0.0-FbnY9hm6nZy14KOKgSllvZ
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji syb-0.7.1-1gO4OjQOULM8usUjWwwEyW
    tar-conduit-0.3.2-AtWElXj0lTb2gnCxvhlD0d template-haskell-2.14.0.0
    text-1.2.3.1 text-metrics-0.3.0-9zUVorhgsUa80G4sTQ4ins
    th-lift-0.8.0.1-27iw5a8l71Jv8yDjPHfmr
    th-lift-instances-0.1.14-KASYyJM441aGLVgajki6ev
    th-orphans-0.13.9-Kj7oG1a3gHoFLKxAz30Iyt
    th-reify-many-0.1.9-G89688xYWjfFURMqNvAi7B
    th-utilities-0.2.3.1-3qJ3GV8o7vFIOfKV3fH5x1 time-1.8.0.2
    transformers-0.5.6.2 unix-compat-0.5.2-GYmNPGqdGR3DF85i5Y9m4X
    unliftio-0.2.12-3yNjSppSs7R15wXSO1FOyS
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    yaml-0.11.2.0-ApNquhXMfTQC9yGRC0uWVw
    zip-archive-0.4.1-6wSxciqkc43Cn55hmSsvpi
haddock-interfaces: /usr/share/doc/haskell-pantry/html/pantry.haddock
haddock-html: /usr/share/doc/haskell-pantry/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pantry-0.1.1.1-64-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pantry.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pantry
version: 0.1.1.1
id: pantry-0.1.1.1-4hnoWMR58A62tBoArp3CvO
key: pantry-0.1.1.1-4hnoWMR58A62tBoArp3CvO
license: BSD-3-Clause
copyright: 2018-2019 FP Complete
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/commercialhaskell/stack#readme
synopsis: Content addressable Haskell package management
description:
    Please see the README on Github at <https://github.com/commercialhaskell/stack/blob/master/subs/pantry/README.md>
category: Development
abi: 41444ab6cd07f87f39fda06b45548913
exposed: True
exposed-modules:
    Pantry Pantry.Internal Pantry.Internal.AesonExtended
    Pantry.Internal.Companion Pantry.Internal.Stackage
    Pantry.Internal.StaticBytes Pantry.SHA256
hidden-modules: Hackage.Security.Client.Repository.HttpLib.HttpClient
                Pantry.Archive Pantry.HTTP Pantry.HPack Pantry.Hackage Pantry.Repo
                Pantry.SQLite Pantry.Storage Pantry.Tree Pantry.Types
                System.IsWindows
import-dirs: /usr/lib/ghc-8.6.5/site-local/pantry-0.1.1.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/pantry-0.1.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/pantry-0.1.1.1
hs-libraries: HSpantry-0.1.1.1-4hnoWMR58A62tBoArp3CvO
depends:
    Cabal-2.4.0.1 aeson-1.4.6.0-Idz88Vw0zug9yYFt0rn4Ut
    ansi-terminal-0.9.1-JvtMBmSUh1eHKvsAMwthXj array-0.5.3.0
    base-4.12.0.0 base-orphans-0.8.1-6XlhSm6oZf21np9NDzyPU3
    base64-bytestring-1.0.0.2-27dSAr8bLTq6kAjQ5MgzSz
    bytestring-0.10.8.2 conduit-1.3.1.1-7uQvxkXSawE7t4T2ZzYFLO
    conduit-extra-1.3.4-JI5NsG2ZqVlCBe03fnfqWX containers-0.6.0.1
    contravariant-1.5.2-IGTyLqhZC2pCTY0qng5HHQ
    cryptonite-0.26-3rNbQlBz8Bk2f3GtKAwmMo
    cryptonite-conduit-0.2.2-B1iuVitzpHF5wMzyF89EJQ deepseq-1.4.4.0
    digest-0.0.1.2-EmnqrtISorTAzGzJuIqcyN directory-1.3.3.0
    filelock-0.1.1.3-FiB0yXqMtv43yiGSEcPU8N filepath-1.4.2.1
    generic-deriving-1.12.4-35jn1EpQs9wLkrWud50div ghc-prim-0.5.3
    hackage-security-0.5.3.0-BRvLWPjeAMBHmRNJmFQnO
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    hpack-0.33.0-8ziYVPR78p47IqUnsnzb3O
    http-client-0.6.4-Dn7ZIQN6KPCeYgFcL4eST
    http-client-tls-0.3.5.3-HR5v3kgs4z56Y3QRCrYz6X
    http-conduit-2.3.7.3-DWaTuCULx3ZCnBxMQ9FMX2
    http-download-0.1.0.0-D9y5dddUGEd1t2nCkqXgSL
    http-types-0.12.3-Coz39hkYXV9BhDskHfFaoY integer-gmp-1.0.2.0
    memory-0.14.18-BrsHMbfyYBXCzXvPhAexth
    mono-traversable-1.0.13.0-oJJbAcoxvEL7oYbbGdR73 mtl-2.2.2
    network-2.8.0.0-GWaLTJJGEavAfd7Abho21R
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    path-0.6.1-F5GNQ955nvDAnwE5yQPzuX
    path-io-1.4.2-4syLlkmGIaJBt32Ebs2jq2
    persistent-2.10.4-HbDov73WTOy2Zh0409kedg
    persistent-sqlite-2.10.5-JLyycNdG6uG8PDYat08pTY
    persistent-template-2.7.3-9Qyow9Efwl79kSZnMmQCtU
    primitive-0.6.4.0-ILgywxtLpvnAOlEISPpP5b
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0
    rio-0.1.12.0-80NoB2Bd2PqDjgUOhHFb0N
    rio-orphans-0.1.1.0-3Jl8bF312YSCVNN0QDJVO0
    rio-prettyprint-0.1.0.0-43S2VylLSUr9EDGk2EgdQ5
    safe-0.3.17-43oyx4B630gDZMbTh3Ttji syb-0.7.1-1gO4OjQOULM8usUjWwwEyW
    tar-conduit-0.3.2-ChULVbsZH7hAoe2e7iMei9 template-haskell-2.14.0.0
    text-1.2.3.1 text-metrics-0.3.0-9zUVorhgsUa80G4sTQ4ins
    th-lift-0.8.0.1-27iw5a8l71Jv8yDjPHfmr
    th-lift-instances-0.1.14-KASYyJM441aGLVgajki6ev
    th-orphans-0.13.9-Kj7oG1a3gHoFLKxAz30Iyt
    th-reify-many-0.1.9-G89688xYWjfFURMqNvAi7B
    th-utilities-0.2.3.1-3qJ3GV8o7vFIOfKV3fH5x1 time-1.8.0.2
    transformers-0.5.6.2 unix-compat-0.5.2-GYmNPGqdGR3DF85i5Y9m4X
    unliftio-0.2.12-3yNjSppSs7R15wXSO1FOyS
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
    yaml-0.11.2.0-Aocsyl3QU6YId6xGXZcrO2
    zip-archive-0.4.1-6wSxciqkc43Cn55hmSsvpi
haddock-interfaces: /usr/share/doc/haskell-pantry/html/pantry.haddock
haddock-html: /usr/share/doc/haskell-pantry/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
